# Word generator (for all you goddam keeb nerds 🤓)

## The story

I was using this funny site to learn Colemak DHm and slowly started realising that the site was (and still is) nowhere near as funny as I thought and came to the conclusion that Monkeytype is signifficantly more funny. Here's the problem: the site was able to generate to generate different level words, such as only using finger keys, or adding adjacent keys to the mix (so like only using `arst` `neio` for example), but Monkeytype has no such feature.

yeah anw this exists now, use it with custom mode in Monkeytype and you can get the ultimate training experience

## Configuration

You can customise the script to your heart's content on the first few lines. I did not and do not plan on adding any interactive elements at this time, if I feel brave enough I might add command line arguments through Click at a later date (or maybe in just an hour or something idk).

i forgor what i was typing about 💀

## Project versioning

`year.breaking.minor`

- `year` of release
- goes up in case there's a `breaking` change
- `minor` goes up with each update

## Credits

- code by Octelly
- top 1000 English words list source: https://gist.github.com/deekayen/4148741 (can be replaced with whatever else if script customisation for personal use like mentioned earlier :D)

## have fun

please have fun please this code is perfect make sure to star ⭐🌟the 🌠repo ✨💫and 🤩*sus*cribe ඞ
